Struct tower_memlim::layer::MemoryLimitLayer
source · pub struct MemoryLimitLayer<M>where
M: AvailableMemory,{ /* private fields */ }Expand description
Enforces a limit on the underlying service when a memory Threshold is met.
A common use case is to load shed (reject requests), once the threshold is met. For doing so you must add tower’s load_shed layer.
Otherwise the service enqueues requests until the memory is available again.
Implementations
sourceimpl<M> MemoryLimitLayer<M>where
M: AvailableMemory,
impl<M> MemoryLimitLayer<M>where
M: AvailableMemory,