Module tower_memlim::error
source · Expand description
Error types
Structs
- An error returned by
MemoryLimitwhen the service’s memory checker was unable to determine the available amount of memory.
Error types
MemoryLimit when the service’s
memory checker was unable to determine the available amount of memory.